@@ -41,7 +41,7 @@ def deploy(resource, authenticator=None, address=None, handle_errors=1):
     class _Deploy(HttpServlet):
         def __init__(self):
             HttpServlet.__init__(self)
-            self.dispatcher = Dispatcher(self.resource, self.authenticator, self.handle_errors)
+            self.dispatcher = Dispatcher(self, self.resource, self.authenticator, self.handle_errors)
 
         def service(self, request, response):
             self.dispatcher.service(request, response)
@@ -56,14 +56,16 @@ class Dispatcher:
 
     "A servlet helper class dispatching requests to WebStack resources."
 
-    def __init__(self, resource, authenticator=None, handle_errors=1):
+    def __init__(self, servlet, resource, authenticator=None, handle_errors=1):
 
         """
-        Initialise the root application-specific 'resource' and optional
-        'authenticator'. The optional 'handle_errors' parameter (if true)
-        causes handlers to deal with uncaught exceptions cleanly.
+        Initialise the dispatcher, providing the deployment 'servlet', the root
+        application-specific 'resource', and an optional 'authenticator'. The
+        optional 'handle_errors' parameter (if true) causes handlers to deal
+        with uncaught exceptions cleanly.
         """
 
+        self.servlet = servlet
         self.webstack_resource = resource
         self.webstack_authenticator = authenticator
         self.handle_errors = handle_errors
@@ -74,7 +76,7 @@ class Dispatcher:
         Handle the 'request' and 'response' presented by the servlet.
         """
 
-        trans = WebStack.JavaServlet.Transaction(request, response)
+        trans = WebStack.JavaServlet.Transaction(request, response, self.servlet)
         try:
             if self.webstack_authenticator is None or self.webstack_authenticator.authenticate(trans):
                 try:
