@@ -22,7 +22,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 import WebStack.Generic
 import os, sys
-from WebStack.Helpers.Request import MessageBodyStream, get_body_fields, decode_value, get_storage_items, Cookie
+from WebStack.Helpers.Request import MessageBodyStream, get_body_fields, \
+    decode_value, get_storage_items, Cookie, HeaderDict
 from WebStack.Helpers.Response import ConvertingStream
 from WebStack.Helpers.Auth import UserInfo
 from WebStack.Helpers.Session import SessionStore
@@ -54,7 +55,7 @@ class Transaction(WebStack.Generic.Transaction):
         self.content_type = None
         self.response_code = 200
         self.content = StringIO()
-        self.headers_out = {}
+        self.headers_out = HeaderDict()
         self.cookies_out = SimpleCookie()
 
         # Define the incoming cookies.
@@ -109,7 +110,7 @@ class Transaction(WebStack.Generic.Transaction):
         """
 
         self.content = StringIO()
-        self.headers_out = {}
+        self.headers_out = HeaderDict()
         self.cookies_out = SimpleCookie()
 
     # Server-related methods.
@@ -296,7 +297,7 @@ class Transaction(WebStack.Generic.Transaction):
 
         if self.storage_body is None:
             self.storage_body = FieldStorage(fp=self.get_request_stream(),
-                headers={"content-type" : str(self.get_content_type())},
+                headers=self.get_headers(),
                 environ={"REQUEST_METHOD" : self.get_request_method()},
                 keep_blank_values=1)
 
