@@ -23,7 +23,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 import shelve
 import random
 import sys
-from WebStack.Repositories.Directory import DirectoryRepository
+import os
+from WebStack.Repositories.Directory import SessionDirectoryRepository
 
 class SessionStore:
 
@@ -44,7 +45,7 @@ class SessionStore:
 
         self.trans = trans
         self.session_cookie_name = session_cookie_name
-        self.repository = DirectoryRepository(session_directory, delay=delay)
+        self.repository = SessionDirectoryRepository(session_directory, delay=delay)
 
         # Internal state.
 
@@ -126,7 +127,9 @@ class SessionStore:
         except KeyError:
             return None
 
-        self.store = shelve.open(store_filename)
+        # NOTE: Using inside knowledge about the repository structure.
+
+        self.store = shelve.open(os.path.join(store_filename, "data"))
         return Wrapper(self.store)
 
     def _get_session_identifier(self):
