@@ -6,6 +6,6 @@ from Simple import SimpleResource
 # Special magic incantation.
 
 print "Serving..."
-deploy(SimpleResource())
+deploy(SimpleResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
