@@ -6,6 +6,6 @@ from VerySimple import VerySimpleResource
 # Special magic incantation.
 
 print "Serving..."
-deploy(VerySimpleResource())
+deploy(VerySimpleResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
