@@ -12,7 +12,7 @@ from Calendar import CalendarResource
 
 # Choose or customise one of the following if the example fails.
 
-deploy(CalendarResource())
-#deploy(CalendarResource("iso-8859-1"))
+deploy(CalendarResource(), handle_errors=0)
+#deploy(CalendarResource("iso-8859-1"), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
