@@ -10,6 +10,6 @@
 from WebStack.Adapters.CGI import deploy
 from Cookies import CookiesResource
 
-deploy(CookiesResource())
+deploy(CookiesResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
