@@ -10,6 +10,6 @@
 from WebStack.Adapters.CGI import deploy
 from Form import FormResource
 
-deploy(FormResource())
+deploy(FormResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
