@@ -10,6 +10,6 @@
 from WebStack.Adapters.CGI import deploy
 from Sessions import SessionsResource
 
-deploy(SessionsResource())
+deploy(SessionsResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
