@@ -10,6 +10,6 @@
 from WebStack.Adapters.CGI import deploy
 from Simple import SimpleResource
 
-deploy(SimpleResource())
+deploy(SimpleResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
