@@ -10,6 +10,6 @@
 from WebStack.Adapters.CGI import deploy
 from Unicode import UnicodeResource
 
-deploy(UnicodeResource())
+deploy(UnicodeResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
