@@ -10,6 +10,6 @@
 from WebStack.Adapters.CGI import deploy
 from VerySimple import VerySimpleResource
 
-deploy(VerySimpleResource())
+deploy(VerySimpleResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
