@@ -5,6 +5,6 @@ from Simple import SimpleResource
 
 resource = SimpleResource()
 
-simple = deploy(resource)
+simple = deploy(resource, handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
