@@ -3,6 +3,6 @@
 from WebStack.Adapters.JavaServlet import deploy
 from Form import FormResource
 
-FormApp = deploy(FormResource())
+FormApp = deploy(FormResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
