@@ -16,6 +16,6 @@ resource = LoginResource(
     use_redirect=0
 )
 
-LoginApp = deploy(resource)
+LoginApp = deploy(resource, handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
