@@ -14,7 +14,8 @@ deploy(
             )
         )
     ),
-    address=("", 8081)
+    address=("", 8081),
+    handle_errors=0
 )
 
 # vim: tabstop=4 expandtab shiftwidth=4
