@@ -7,10 +7,10 @@
 #sys.path.append("/home/paulb/Software/Python/WebStack")
 #sys.path.append("/home/paulb/Software/Python/WebStack/examples/Common")
 
-from WebStack.Adapters.WSGI import deploy
+from WebStack.Adapters.WSGI import deploy_as_cgi
 from WebStack.Resources.Login import LoginResource, LoginAuthenticator
 
-deploy(
+deploy_as_cgi(
     LoginResource(
         LoginAuthenticator(
             secret_key="horses",
@@ -19,7 +19,8 @@ deploy(
                 ("vole", "xyz"),
             )
         )
-    )
+    ),
+    handle_errors=0
 )
 
 # vim: tabstop=4 expandtab shiftwidth=4
