@@ -7,9 +7,9 @@
 #sys.path.append("/home/paulb/Software/Python/WebStack")
 #sys.path.append("/home/paulb/Software/Python/WebStack/examples/Common")
 
-from WebStack.Adapters.WSGI import deploy
+from WebStack.Adapters.WSGI import deploy_as_cgi
 from Sessions import SessionsResource
 
-deploy(SessionsResource())
+deploy_as_cgi(SessionsResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
