@@ -7,9 +7,9 @@
 #sys.path.append("/home/paulb/Software/Python/WebStack")
 #sys.path.append("/home/paulb/Software/Python/WebStack/examples/Common")
 
-from WebStack.Adapters.WSGI import deploy
+from WebStack.Adapters.WSGI import deploy_as_cgi
 from Simple import SimpleResource
 
-deploy(SimpleResource())
+deploy_as_cgi(SimpleResource(), handle_errors=0)
 
 # vim: tabstop=4 expandtab shiftwidth=4
